# optika

[![tests](https://github.com/byrdie/optika/actions/workflows/tests.yml/badge.svg)](https://github.com/byrdie/optika/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/byrdie/optika/graph/badge.svg?token=P91YBOT47O)](https://codecov.io/gh/byrdie/optika)
[![Black](https://github.com/byrdie/optika/actions/workflows/black.yml/badge.svg)](https://github.com/byrdie/optika/actions/workflows/black.yml)
[![Documentation Status](https://readthedocs.org/projects/optika/badge/?version=latest)](https://optika.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/optika.svg)](https://badge.fury.io/py/optika)

A Python library for simulating optical systems, similar to Zemax
